@@ -95,7 +95,9 @@ warn <- function(message = NULL,
                  ...,
                  body = NULL,
                  footer = NULL,
+                 parent = NULL,
                  use_cli_format = NULL,
+                 .inherit = NULL,
                  .frequency = c("always", "regularly", "once"),
                  .frequency_id = NULL,
                  .subclass = deprecated()) {
@@ -117,11 +119,24 @@ warn <- function(message = NULL,
     return(invisible(NULL))
   }
 
+  if (!is_null(parent)) {
+    # Don't inherit from `parent` by default if chained to a
+    # downgraded error
+    if (is_null(.inherit)) {
+      .inherit <- !inherits(parent, "error")
+    }
+    extra_fields$rlang <- c(
+      extra_fields$rlang,
+      list(inherit = .inherit)
+    )
+  }
+
   cnd <- warning_cnd(
     class,
     message = message,
     !!!extra_fields,
     use_cli_format = use_cli_format,
+    parent = parent,
     ...
   )
   cnd$footer <- c(cnd$footer, message_freq(message, .frequency, "warning"))
@@ -136,7 +151,9 @@ inform <- function(message = NULL,
                    ...,
                    body = NULL,
                    footer = NULL,
+                   parent = NULL,
                    use_cli_format = NULL,
+                   .inherit = NULL,
                    .file = NULL,
                    .frequency = c("always", "regularly", "once"),
                    .frequency_id = NULL,
@@ -161,10 +178,23 @@ inform <- function(message = NULL,
     return(invisible(NULL))
   }
 
+  if (!is_null(parent)) {
+    # Don't inherit from `parent` by default if chained to a
+    # downgraded warning or error
+    if (is_null(.inherit)) {
+      .inherit <- !inherits(parent, c("warning", "error"))
+    }
+    extra_fields$rlang <- c(
+      extra_fields$rlang,
+      list(inherit = .inherit)
+    )
+  }
+
   cnd <- message_cnd(
     class,
     message = message,
     !!!extra_fields,
+    parent = parent,
     use_cli_format = use_cli_format,
     ...
   )
@@ -180,7 +210,7 @@ inform <- function(message = NULL,
 }
 #' @rdname abort
 #' @export
-signal <- function(message,
+signal <- function(message = "",
                    class,
                    ...,
                    .subclass = deprecated()) {
@@ -239,7 +269,7 @@ deprecate_subclass <- function(subclass, fn, env = caller_env()) {
   # - https://github.com/NikKrieger/sociome/issues/14
   # - https://github.com/r-lib/testthat/commit/f09df60dd881530332b252474e9f35c97f8640be
   if (is_true(peek_option("force_subclass_deprecation"))) {
-    signal_soft_deprecated(msg)
+    deprecate_soft(msg)
   }
   env_bind(env, class = subclass)
 }
@@ -327,7 +357,7 @@ needs_signal <- function(frequency,
       format_arg(".frequency")
     ))
   }
-  check_string(id, arg = ".frequency")
+  check_name(id, arg = ".frequency")
 
   sentinel <- env[[id]]
   if (is_null(sentinel)) {
@@ -368,7 +398,7 @@ reset_message_verbosity <- function(id) {
   reset_verbosity(id, "message")
 }
 reset_verbosity <- function(id, type = c("message", "warning")) {
-  check_string(id)
+  check_name(id)
   type <- arg_match(type)
 
   env <- switch(
